@@ -2,13 +2,21 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) any later version.
+   modify it under the terms of the GNU General Public License,
+   version 2, as published by the Free Software Foundation.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,7 +26,7 @@
    You should have received a copy of the GNU General Public License
    along with the LZO library; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
@@ -97,6 +105,7 @@ int __lzo_cdecl_main main(int argc, char *argv[])
     lzo_uint in_len;
 
     lzo_bytep out;
+    lzo_uint out_bufsize;
     lzo_uint out_len = 0;
 
     lzo_bytep wrkmem;
@@ -180,13 +189,14 @@ int __lzo_cdecl_main main(int argc, char *argv[])
         exit(1);
     }
     in_len = (lzo_uint) l;
+    out_bufsize = in_len + in_len / 16 + 64 + 3;
     best_len = in_len;
 
 /*
  * Step 4: allocate compression buffers and read the file
  */
     in = (lzo_bytep) lzo_malloc(in_len);
-    out = (lzo_bytep) lzo_malloc(in_len + in_len / 16 + 64 + 3);
+    out = (lzo_bytep) lzo_malloc(out_bufsize);
     if (in == NULL || out == NULL)
     {
         printf("%s: out of memory\n", progname);
@@ -208,6 +218,7 @@ int __lzo_cdecl_main main(int argc, char *argv[])
 #ifdef USE_LZO1X
     for (lazy = 0; lazy <= max_try_lazy; lazy++)
     {
+        out_len = out_bufsize;
         r = lzo1x_999_compress_internal(in,in_len,out,&out_len,wrkmem,
                                         NULL, 0, 0,
                                         lazy, big, big, big, big, flags);
@@ -234,6 +245,7 @@ int __lzo_cdecl_main main(int argc, char *argv[])
 #ifdef USE_LZO1Y
     for (lazy = 0; lazy <= max_try_lazy; lazy++)
     {
+        out_len = out_bufsize;
         r = lzo1y_999_compress_internal(in,in_len,out,&out_len,wrkmem,
                                         NULL, 0, 0,
                                         lazy, big, big, big, big, flags);
@@ -266,6 +278,7 @@ int __lzo_cdecl_main main(int argc, char *argv[])
 /*
  * Step 8: compress data again using the best compressor found
  */
+    out_len = out_bufsize;
     if (best_compress == 1)
         r = lzo1x_999_compress_internal(in,in_len,out,&out_len,wrkmem,
                                         NULL, 0, 0,
