@@ -2,13 +2,21 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) any later version.
+   modify it under the terms of the GNU General Public License,
+   version 2, as published by the Free Software Foundation.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,10 +26,11 @@
    You should have received a copy of the GNU General Public License
    along with the LZO library; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzo/
  */
 
 
@@ -34,8 +43,8 @@
 #ifndef __LZO_CONFIG1C_H
 #define __LZO_CONFIG1C_H
 
-#include <lzo1c.h>
 #include "lzo_conf.h"
+#include "lzo/lzo1c.h"
 
 
 /***********************************************************************
@@ -45,19 +54,19 @@
 /* run bits (4 - 5) - the compressor and the decompressor
  * must use the same value. */
 #if !defined(RBITS)
-#  define RBITS		5
+#  define RBITS     5
 #endif
 
 /* dictionary depth (0 - 6) - this only affects the compressor.
  * 0 is fastest, 6 is best compression ratio */
 #if !defined(DDBITS)
-#  define DDBITS	0
+#  define DDBITS    0
 #endif
 
 /* compression level (1 - 9) - this only affects the compressor.
  * 1 is fastest, 9 is best compression ratio */
 #if !defined(CLEVEL)
-#  define CLEVEL	1			/* fastest by default */
+#  define CLEVEL    1           /* fastest by default */
 #endif
 
 
@@ -79,12 +88,8 @@
 
 /* add a special code so that the decompressor can detect the
  * end of the compressed data block (overhead is 3 bytes per block) */
-#undef LZO_EOF_CODE
 #define LZO_EOF_CODE
 
-/* return -1 instead of copying if the data cannot be compressed */
-#undef LZO_RETURN_IF_NOT_COMPRESSIBLE
-
 
 /***********************************************************************
 // algorithm internal configuration
@@ -92,14 +97,14 @@
 
 /* choose the hashing strategy */
 #ifndef LZO_HASH
-#define LZO_HASH		LZO_HASH_LZO_INCREMENTAL_A
+#define LZO_HASH        LZO_HASH_LZO_INCREMENTAL_A
 #endif
 
 /* config */
-#define R_BITS			RBITS
-#define DD_BITS			DDBITS
+#define R_BITS          RBITS
+#define DD_BITS         DDBITS
 #ifndef D_BITS
-#define D_BITS			14
+#define D_BITS          14
 #endif
 
 
@@ -118,11 +123,10 @@
 ************************************************************************/
 
 /* good parameters when using a blocksize of 8kB */
-#define M3O_BITS		6
+#define M3O_BITS        6
 #undef LZO_DETERMINISTIC
 
 
-#include "lzo_util.h"
 #include "lzo1b_de.h"
 #include "stats1c.h"
 
