@@ -2,13 +2,21 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2005 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2004 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) any later version.
+   modify it under the terms of the GNU General Public License,
+   version 2, as published by the Free Software Foundation.
 
    The LZO library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,10 +26,11 @@
    You should have received a copy of the GNU General Public License
    along with the LZO library; see the file COPYING.
    If not, write to the Free Software Foundation, Inc.,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
    Markus F.X.J. Oberhumer
    <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzo/
  */
 
 
@@ -56,19 +65,19 @@ extern const lzo_compress_t _lzo1c_99_compress_func;
 //
 ************************************************************************/
 
-LZO_EXTERN(lzo_byte *)
-_lzo1c_store_run ( lzo_byte * const oo, const lzo_byte * const ii,
-				   lzo_uint r_len);
+LZO_EXTERN(lzo_bytep )
+_lzo1c_store_run ( lzo_bytep const oo, const lzo_bytep const ii,
+                   lzo_uint r_len);
 
-#define STORE_RUN	_lzo1c_store_run
+#define STORE_RUN   _lzo1c_store_run
 
 
 lzo_compress_t _lzo1c_get_compress_func(int clevel);
 
-int _lzo1c_do_compress   ( const lzo_byte *in,  lzo_uint  in_len,
-								 lzo_byte *out, lzo_uintp out_len,
-								 lzo_voidp wrkmem,
-								 lzo_compress_t func );
+int _lzo1c_do_compress   ( const lzo_bytep in,  lzo_uint  in_len,
+                                 lzo_bytep out, lzo_uintp out_len,
+                                 lzo_voidp wrkmem,
+                                 lzo_compress_t func );
 
 
 #endif /* already included */
