@@ -16,9 +16,8 @@
 
 
 while (<>) {
-
-    if (substr($_,52) =~ /^\s+[\d\.]+\s+[\d\.]+\s+\|\s*\n$/i) {
-        substr($_,52) = "      0.00      0.00 |\n";
+    if (substr($_,56) =~ /^\s+[\d\.]+\s+[\d\.]+\s+\|\s*\n$/) {
+        substr($_,56) = "     0.000     0.000 |\n";
     }
     print;
 }
